@@ -14,14 +14,13 @@ from quodlibet import config
 from quodlibet.qltk.entry import UndoEntry
 from quodlibet.qltk import Icons
 from quodlibet.util.string import decode
-from quodlibet.util import gdecode
 from quodlibet.plugins.events import EventPlugin
 from quodlibet.compat import text_type
 
 
 def _config(section, option, label, tooltip=None, getter=None):
     def on_changed(entry, *args):
-        config.settext(section, option, gdecode(entry.get_text()))
+        config.settext(section, option, entry.get_text())
 
     entry = UndoEntry()
     if tooltip:
@@ -153,6 +152,14 @@ class AdvancedPreferences(EventPlugin):
                 "DateColumn timestamp format",
                 "A timestamp format, e.g. %Y%m%d %X "))
 
+        rows.append(
+            text_config(
+                "settings", "scrollbar_always_visible",
+                "Scrollbars always visible:",
+                ("Toggles whether the scrollbars on the bottom and side of "
+                 "the window always are visible or get hidden when not in use "
+                 "(restart required)")))
+
         for (row, (label, entry, button)) in enumerate(rows):
             label.set_alignment(1.0, 0.5)
             table.attach(label, 0, 1, row, row + 1,
