@@ -106,6 +106,8 @@ value="false"/>
         name = dbus.service.BusName(self.BUS_NAME, bus)
         MPRISObject.__init__(self, bus, self.PATH, name)
 
+        self.__metadata = None
+        self.__cover = None
         player_options = app.player_options
         self.__repeat_id = player_options.connect(
             "notify::repeat", self.__repeat_changed)
@@ -122,7 +124,6 @@ value="false"/>
     def remove_from_connection(self, *arg, **kwargs):
         super(MPRIS2, self).remove_from_connection(*arg, **kwargs)
 
-        self.__cover = None
         player_options = app.player_options
         player_options.disconnect(self.__repeat_id)
         player_options.disconnect(self.__random_id)
@@ -131,6 +132,11 @@ value="false"/>
         app.player.disconnect(self.__vsig)
         app.player.disconnect(self.__seek_sig)
 
+        if self.__cover is not None:
+            self.__cover.close()
+            self.__cover = None
+        self.__invalidate_metadata()
+
     def __volume_changed(self, *args):
         self.emit_properties_changed(self.PLAYER_IFACE, ["Volume"])
 
@@ -147,6 +153,7 @@ value="false"/>
         self.Seeked(ms * 1000)
 
     def __library_changed(self, library, songs):
+        self.__invalidate_metadata()
         if not songs or app.player.info not in songs:
             return
         self.emit_properties_changed(self.PLAYER_IFACE, ["Metadata"])
@@ -208,6 +215,8 @@ value="false"/>
     unpaused = paused
 
     def song_started(self, song):
+        self.__invalidate_metadata()
+
         # so the position in clients gets updated faster
         self.Seeked(0)
 
@@ -220,7 +229,16 @@ value="false"/>
             return dbus.ObjectPath(path + "/" + "NoTrack")
         return dbus.ObjectPath(path + "/" + str(id(app.player.info)))
 
+    def __invalidate_metadata(self):
+        self.__metadata = None
+
     def __get_metadata(self):
+        if self.__metadata is None:
+            self.__metadata = self.__get_metadata_real()
+            assert self.__metadata is not None
+        return self.__metadata
+
+    def __get_metadata_real(self):
         """
         https://www.freedesktop.org/wiki/Specifications/mpris-spec/metadata/
         """
@@ -241,18 +259,17 @@ value="false"/>
         metadata["mpris:length"] = ignore_overflow(
             dbus.Int64, song("~#length") * 10 ** 6)
 
-        self.__cover = cover = app.cover_manager.get_cover(song)
-        is_temp = False
-        if cover:
-            name = cover.name
-            is_temp = name.startswith(tempfile.gettempdir())
-            # This doesn't work for embedded images.. the file gets unlinked
-            # after loosing the file handle
-            metadata["mpris:artUrl"] = fsn2uri(name)
-
-        if not is_temp:
+        if self.__cover is not None:
+            self.__cover.close()
             self.__cover = None
 
+        cover = app.cover_manager.get_cover(song)
+        if cover:
+            is_temp = cover.name.startswith(tempfile.gettempdir())
+            if is_temp:
+                self.__cover = cover
+            metadata["mpris:artUrl"] = fsn2uri(cover.name)
+
         # All list values
         list_val = {"artist": "artist", "albumArtist": "albumartist",
             "comment": "comment", "composer": "composer", "genre": "genre",
@@ -341,7 +358,7 @@ value="false"/>
             elif name == "Identity":
                 return app.name
             elif name == "DesktopEntry":
-                return "quodlibet"
+                return "io.github.quodlibet.QuodLibet"
             elif name == "SupportedUriSchemes":
                 # TODO: enable once OpenUri is done
                 can = lambda s: False
