@@ -4,8 +4,9 @@
 #      2012,2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import os
 import sys
@@ -17,6 +18,7 @@ if os.name == "nt" or sys.platform == "darwin":
 import dbus
 from gi.repository import Gtk
 
+from quodlibet import _
 from quodlibet.pattern import Pattern
 from quodlibet.qltk.entry import UndoEntry
 from quodlibet import util
