@@ -2,8 +2,9 @@
 # Copyright 2016 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from mutagen.aiff import AIFF
 
@@ -21,6 +22,7 @@ class AIFFFile(ID3File):
     def _parse_info(self, info):
         self["~#length"] = info.length
         self["~#bitrate"] = int(info.bitrate / 1000)
+        self["~#channels"] = info.channels
 
 
 loader = AIFFFile
