@@ -2,8 +2,9 @@
 # Copyright 2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from quodlibet import config
 from quodlibet.util import print_d
@@ -16,11 +17,12 @@ def iter_backends():
         return
 
     try:
-        from .gnome import GnomeBackend, MateBackend
+        from .gnome import GnomeBackend, GnomeBackendOldName, MateBackend
     except MMKeysImportError:
         pass
     else:
         yield GnomeBackend
+        yield GnomeBackendOldName
         yield MateBackend
 
     try:
@@ -90,21 +92,15 @@ class MMKeysHandler(object):
 
         player = self._player
         if action == MMKeysAction.PREV:
-            player.previous()
+            player.previous(force=True)
         elif action == MMKeysAction.NEXT:
             player.next()
         elif action == MMKeysAction.STOP:
             player.stop()
         elif action == MMKeysAction.PLAY:
-            if player.song is None:
-                player.reset()
-            else:
-                player.paused = False
+            player.play()
         elif action == MMKeysAction.PLAYPAUSE:
-            if player.song is None:
-                player.reset()
-            else:
-                player.paused ^= True
+            player.playpause()
         elif action == MMKeysAction.PAUSE:
             player.paused = True
         else:
