@@ -3,8 +3,9 @@
 # Christoph Reiter, Nick Boultbee, Simonas Kazlauskas
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk, GLib, Gdk, GdkPixbuf, Gio, GObject
 from senf import fsnative
@@ -41,8 +42,8 @@ class BigCenteredImage(qltk.Window):
             width = int(width / 1.1)
             height = int(height / 1.1)
         else:
-            width = int(Gdk.Screen.width() / 1.75)
-            height = int(Gdk.Screen.height() / 1.75)
+            width = int(Gdk.Screen.width() / 1.8)
+            height = int(Gdk.Screen.height() / 1.8)
 
         self.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
 
@@ -240,7 +241,7 @@ class CoverImage(Gtk.EventBox):
         self.set_image(None)
         if self.__cancellable:
             self.__cancellable.cancel()
-        cancellable = self.__cancellable = Gio.Cancellable.new()
+        cancellable = self.__cancellable = Gio.Cancellable()
 
         if song:
             def cb(success, result):
