@@ -23,9 +23,9 @@ try:
 except ImportError:
     fcntl = None
 
-from senf import fsnative, environ, argv
+from senf import fsnative, argv
 
-from quodlibet.compat import reraise as py_reraise, PY2, text_type, \
+from quodlibet.compat import reraise as py_reraise, text_type, \
     iteritems, reduce, number_types, long
 from quodlibet.util.string.titlecase import title
 
@@ -45,20 +45,6 @@ is_linux, is_windows, is_wine, is_osx, get_module_dir, get_ca_file,
 get_locale_encoding, NamedTemporaryFile
 
 
-if PY2:
-    def gdecode(s):
-        """Returns unicode for the glib text type"""
-
-        assert isinstance(s, bytes)
-        return s.decode("utf-8")
-else:
-    def gdecode(s):
-        """Returns unicode for the glib text type"""
-
-        assert isinstance(s, text_type)
-        return s
-
-
 class InstanceTracker(object):
     """A mixin for GObjects to return a list of all alive objects
     of a given type. Note that it must be used with a GObject or
@@ -773,7 +759,7 @@ class cached_property(object):
         self.fget = fget
         self.__doc__ = doc or fget.__doc__
         self.__name__ = name = fget.__name__
-        # these get name mangled, so caching wont work unless
+        # these get name mangled, so caching won't work unless
         # we mangle too
         assert not (name.startswith("__") and not name.endswith("__")), \
             "can't cache a dunder method"
@@ -957,17 +943,6 @@ def load_library(names, shared=True):
     else:
         load_func = ctypes.cdll.LoadLibrary
 
-    if is_osx():
-        # make sure it's either empty or contains /usr/lib.
-        # (jhbuild sets it for example). Otherwise ctypes can't
-        # find libc (bug?)
-        if "DYLD_FALLBACK_LIBRARY_PATH" in environ:
-            paths = environ["DYLD_FALLBACK_LIBRARY_PATH"]
-            paths = paths.split(os.pathsep)
-            if "/usr/lib" not in paths:
-                paths.append("/usr/lib")
-                environ["DYLD_FALLBACK_LIBRARY_PATH"] = os.pathsep.join(paths)
-
     errors = []
     for name in names:
         dlopen_name = name
@@ -975,6 +950,9 @@ def load_library(names, shared=True):
                 ".dylib" not in name:
             dlopen_name = ctypes.util.find_library(name) or name
 
+        if is_osx() and not os.path.isabs(dlopen_name):
+            dlopen_name = os.path.join(sys.prefix, "lib", dlopen_name)
+
         try:
             return load_func(dlopen_name), name
         except OSError as e:
@@ -1127,11 +1105,22 @@ def set_process_title(title):
 
     try:
         libc = load_library(["libc.so.6", "c"])[0]
-        # 15 = PR_SET_NAME, apparently
-        libc.prctl(15, title, 0, 0, 0)
+        prctl = libc.prctl
     except (OSError, AttributeError):
         print_d("Couldn't find module libc.so.6 (ctypes). "
                 "Not setting process title.")
+    else:
+        prctl.argtypes = [
+            ctypes.c_int, ctypes.c_ulong, ctypes.c_ulong,
+            ctypes.c_ulong, ctypes.c_ulong,
+        ]
+        prctl.restype = ctypes.c_int
+
+        PR_SET_NAME = 15
+        data = ctypes.create_string_buffer(title.encode("utf-8"))
+        res = prctl(PR_SET_NAME, ctypes.addressof(data), 0, 0, 0)
+        if res != 0:
+            print_w("Setting the process title failed")
 
 
 def list_unique(sequence):
