@@ -4,8 +4,9 @@
 #           2011-2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 """Simple proxy to a Python ConfigParser
 
@@ -123,7 +124,10 @@ class Config(object):
 
         assert self.defaults is not None
 
-        self.set(section, option, self.defaults.get(section, option))
+        try:
+            self._config.remove_option(section, option)
+        except NoSectionError:
+            pass
 
     def options(self, section):
         """Returns a list of options available in the specified section."""
